@@ -31,7 +31,7 @@ class HSResult:
         self.data = data
         return self
 
-
+# 消息答应分隔符
 def line(number = None,message = None):
     if number == None:
         number = 0
@@ -43,3 +43,33 @@ def line(number = None,message = None):
     if message != None:
         print('    ' + message)
         print("    ----------------" )
+
+# 各种类型都转换成字符串
+def toString(obj = None):
+    if(obj == None):
+        return ""
+    if isinstance(obj,int):
+        return str(obj)
+    if isinstance(obj,float):
+        return str(obj)
+    if isinstance(obj,bool):
+        return str(bool)
+    if isinstance(obj,str):
+        return str
+    raise Exception("未知类型")
+
+# 将对象转换成json
+def toJSON(obj):
+    return json.dumps(obj,ensure_ascii=False,default=lambda o: o.__dict__, sort_keys=True, indent=4)
+
+# 做方法测试
+if __name__ == '__main__':
+    print(toJSON({"a":1,"b":2}))
+    print(toJSON({
+        "a":1,
+        "b":2,
+        "c":{
+            "a1":1,
+            "b1":2
+        }
+    }))
